==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/mprisplayer_mediaplayer/translations/mprisplayer_mediaplayer_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>MPRIS Player</source>
        <translation>Odtwarzacz zgodny ze standardem MPRIS</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerConfigurationUiHandler</name>
    <message>
        <source>Select Player:</source>
        <translation>Wybierz odtwarzacz:</translation>
    </message>
    <message>
        <source>Add Player</source>
        <translation>Dodaj odtwarzacz</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Edytuj odtwarzacz</translation>
    </message>
    <message>
        <source>Delete Player</source>
        <translation>Usuń odtwarzacz</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerDialog</name>
    <message>
        <source>Edit Player</source>
        <translation>Edytuj odtwarzacz</translation>
    </message>
    <message>
        <source>Add Player</source>
        <translation>Dodaj odtwarzacz</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Odtwarzacz:</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Usługa:</translation>
    </message>
</context>
</TS>

==> kadu_1.3.orig.tar.bz2: kadu-1.3/plugins/mprisplayer_mediaplayer/translations/mprisplayer_mediaplayer_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>MPRIS Player</source>
        <translation>Odtwarzacz zgodny ze standardem MPRIS</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerConfigurationUiHandler</name>
    <message>
        <source>Select Player:</source>
        <translation>Wybierz odtwarzacz:</translation>
    </message>
    <message>
        <source>Add Player</source>
        <translation>Dodaj odtwarzacz</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Edytuj odtwarzacz</translation>
    </message>
    <message>
        <source>Delete Player</source>
        <translation>Usuń odtwarzacz</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerDialog</name>
    <message>
        <source>Add Player</source>
        <translation>Dodaj odtwarzacz</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Edytuj odtwarzacz</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Odtwarzacz:</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Usługa:</translation>
    </message>
</context>
</TS>
